"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readNxCloudToken = readNxCloudToken;
exports.getOnboardingInfo = getOnboardingInfo;
const output_1 = require("../output");
const messages_1 = require("./messages");
const ora = require("ora");
function readNxCloudToken(directory) {
    const nxCloudSpinner = ora(`Checking Nx Cloud setup`).start();
    // nx-ignore-next-line
    const { getCloudOptions } = require(require.resolve('nx/src/nx-cloud/utilities/get-cloud-options', {
        paths: [directory],
    }
    // nx-ignore-next-line
    ));
    const { accessToken, nxCloudId } = getCloudOptions(directory);
    nxCloudSpinner.succeed('Nx Cloud has been set up successfully');
    return accessToken || nxCloudId;
}
async function getOnboardingInfo(nxCloud, token, directory, useGithub) {
    // nx-ignore-next-line
    const { createNxCloudOnboardingURL } = require(require.resolve('nx/src/nx-cloud/utilities/url-shorten', {
        paths: [directory],
    }
    // nx-ignore-next-line
    ));
    const source = nxCloud === 'yes'
        ? 'create-nx-workspace-success-cache-setup'
        : 'create-nx-workspace-success-ci-setup';
    const { code, createMessage } = (0, messages_1.getMessageFactory)(source);
    const connectCloudUrl = await createNxCloudOnboardingURL(source, token, useGithub ??
        (nxCloud === 'yes' || nxCloud === 'github' || nxCloud === 'circleci'), code);
    const out = new output_1.CLIOutput(false);
    const message = createMessage(connectCloudUrl);
    if (message.type === 'success') {
        out.success(message);
    }
    else {
        out.warn(message);
    }
    return { output: out.getOutput(), connectCloudUrl };
}
